@@ -21,12 +21,13 @@ class OpenCTIApiConnector:
         logging.info("Getting connectors ...")
         query = """
             query GetConnectors {
-                connectors {
+                connectorsForWorker {
                     id
                     name
                     config {
                         connection {
                             host
+                            vhost
                             use_ssl
                             port
                             user
@@ -39,7 +40,7 @@ class OpenCTIApiConnector:
             }
         """
         result = self.api.query(query)
-        return result["data"]["connectors"]
+        return result["data"]["connectorsForWorker"]
 
     def ping(self, connector_id: str, connector_state: Any) -> Dict:
         """pings a connector by id and state
@@ -82,6 +83,7 @@ class OpenCTIApiConnector:
                     config {
                         connection {
                             host
+                            vhost
                             use_ssl
                             port
                             user
@@ -92,11 +94,24 @@ class OpenCTIApiConnector:
                         push
                         push_exchange
                     }
-                    connector_user {
-                        id
-                    }
+                    connector_user_id
                 }
             }
            """
         result = self.api.query(query, connector.to_input())
         return result["data"]["registerConnector"]
+
+    def unregister(self, _id: str) -> Dict:
+        """unregister a connector with OpenCTI
+
+        :param _id: `OpenCTIConnector` connector id
+        :type _id: string
+        :return: the response registerConnector data dict
+        :rtype: dict
+        """
+        query = """
+            mutation ConnectorDeletionMutation($id: ID!) {
+                deleteConnector(id: $id)
+            }
+        """
+        return self.api.query(query, {"id": _id})
