@@ -1,6 +1,9 @@
 # coding: utf-8
 
 import json
+import uuid
+
+from stix2.canonicalization.Canonicalize import canonicalize
 
 
 class ObservedData:
@@ -37,7 +40,7 @@ class ObservedData:
                                 color
                             }
                         }
-                    }                    
+                    }
                 }
                 ... on Organization {
                     x_opencti_organization_type
@@ -183,7 +186,7 @@ class ObservedData:
                         }
                         ... on Incident {
                             name
-                        }                
+                        }
                         ... on StixCoreRelationship {
                             standard_id
                             spec_version
@@ -208,6 +211,13 @@ class ObservedData:
             }
         """
 
+    @staticmethod
+    def generate_id(object_ids):
+        data = {"objects": object_ids}
+        data = canonicalize(data, utf8=False)
+        id = str(uuid.uuid5(uuid.UUID("00abedb4-aa42-466c-9c01-fed23315a9b7"), data))
+        return "observed-data--" + id
+
     """
         List ObservedData objects
 
@@ -251,7 +261,7 @@ class ObservedData:
                         hasNextPage
                         hasPreviousPage
                         globalCount
-                    }                    
+                    }
                 }
             }
         """
@@ -311,7 +321,7 @@ class ObservedData:
 
     """
         Check if a observedData already contains a STIX entity
-        
+
         :return Boolean
     """
 
@@ -358,6 +368,7 @@ class ObservedData:
     def create(self, **kwargs):
         stix_id = kwargs.get("stix_id", None)
         created_by = kwargs.get("createdBy", None)
+        objects = kwargs.get("objects", None)
         object_marking = kwargs.get("objectMarking", None)
         object_label = kwargs.get("objectLabel", None)
         external_references = kwargs.get("externalReferences", None)
@@ -369,7 +380,6 @@ class ObservedData:
         first_observed = kwargs.get("first_observed", None)
         last_observed = kwargs.get("last_observed", None)
         number_observed = kwargs.get("number_observed", None)
-        objects = kwargs.get("objects", None)
         x_opencti_stix_ids = kwargs.get("x_opencti_stix_ids", None)
         update = kwargs.get("update", False)
 
@@ -385,7 +395,7 @@ class ObservedData:
                         id
                         standard_id
                         entity_type
-                        parent_types                     
+                        parent_types
                     }
                 }
             """
@@ -397,6 +407,7 @@ class ObservedData:
                         "createdBy": created_by,
                         "objectMarking": object_marking,
                         "objectLabel": object_label,
+                        "objects": objects,
                         "externalReferences": external_references,
                         "revoked": revoked,
                         "confidence": confidence,
@@ -406,7 +417,6 @@ class ObservedData:
                         "first_observed": first_observed,
                         "last_observed": last_observed,
                         "number_observed": number_observed,
-                        "objects": objects,
                         "x_opencti_stix_ids": x_opencti_stix_ids,
                         "update": update,
                     }
@@ -498,7 +508,7 @@ class ObservedData:
                 + "}",
             )
             query = """
-               mutation ObservedDataEditRelationDelete($id: ID!, $toId: String!, $relationship_type: String!) {
+               mutation ObservedDataEditRelationDelete($id: ID!, $toId: StixRef!, $relationship_type: String!) {
                    observedDataEdit(id: $id) {
                         relationDelete(toId: $toId, relationship_type: $relationship_type) {
                             id
@@ -532,6 +542,7 @@ class ObservedData:
         stix_object = kwargs.get("stixObject", None)
         extras = kwargs.get("extras", {})
         update = kwargs.get("update", False)
+        object_refs = extras["object_ids"] if "object_ids" in extras else []
 
         if "objects" in stix_object:
             stix_observable_results = []
@@ -550,12 +561,17 @@ class ObservedData:
                         else [],
                     )
                 )
-                refs = []
                 for item in stix_observable_results:
-                    refs.append(item["standard_id"])
-                stix_object["object_refs"] = refs
+                    object_refs.append(item["standard_id"])
 
         if stix_object is not None:
+
+            # Search in extensions
+            if "x_opencti_stix_ids" not in stix_object:
+                stix_object[
+                    "x_opencti_stix_ids"
+                ] = self.opencti.get_attribute_in_extension("stix_ids", stix_object)
+
             observed_data_result = self.create(
                 stix_id=stix_object["id"],
                 createdBy=extras["created_by_id"]
@@ -567,6 +583,7 @@ class ObservedData:
                 objectLabel=extras["object_label_ids"]
                 if "object_label_ids" in extras
                 else [],
+                objects=object_refs,
                 externalReferences=extras["external_references_ids"]
                 if "external_references_ids" in extras
                 else [],
@@ -586,9 +603,6 @@ class ObservedData:
                 number_observed=stix_object["number_observed"]
                 if "number_observed" in stix_object
                 else None,
-                objects=stix_object["object_refs"]
-                if "object_refs" in stix_object
-                else None,
                 x_opencti_stix_ids=stix_object["x_opencti_stix_ids"]
                 if "x_opencti_stix_ids" in stix_object
                 else None,
