@@ -1,6 +1,7 @@
 # coding: utf-8
 
 import json
+import uuid
 
 
 class Opinion:
@@ -21,6 +22,7 @@ class Opinion:
                     entity_type
                     parent_types
                     spec_version
+                    identity_class
                     name
                     description
                     roles
@@ -36,7 +38,7 @@ class Opinion:
                                 color
                             }
                         }
-                    }                    
+                    }
                 }
                 ... on Organization {
                     x_opencti_organization_type
@@ -84,6 +86,19 @@ class Opinion:
                         external_id
                         created
                         modified
+                        importFiles {
+                            edges {
+                                node {
+                                    id
+                                    name
+                                    size
+                                    metaData {
+                                        mimetype
+                                        version
+                                    }
+                                }
+                            }
+                        }
                     }
                 }
             }
@@ -131,6 +146,9 @@ class Opinion:
                         ... on Sector {
                             name
                         }
+                        ... on System {
+                            name
+                        }
                         ... on Indicator {
                             name
                         }
@@ -166,7 +184,7 @@ class Opinion:
                         }
                         ... on Incident {
                             name
-                        }                
+                        }
                         ... on StixCoreRelationship {
                             standard_id
                             spec_version
@@ -177,8 +195,25 @@ class Opinion:
                     }
                 }
             }
+            importFiles {
+                edges {
+                    node {
+                        id
+                        name
+                        size
+                        metaData {
+                            mimetype
+                            version
+                        }
+                    }
+                }
+            }
         """
 
+    @staticmethod
+    def generate_id():
+        return "opinion--" + str(uuid.uuid4())
+
     """
         List Opinion objects
 
@@ -222,7 +257,7 @@ class Opinion:
                         hasNextPage
                         hasPreviousPage
                         globalCount
-                    }                    
+                    }
                 }
             }
         """
@@ -304,7 +339,7 @@ class Opinion:
 
     """
         Check if a opinion already contains a STIX entity
-        
+
         :return Boolean
     """
 
@@ -351,6 +386,7 @@ class Opinion:
     def create(self, **kwargs):
         stix_id = kwargs.get("stix_id", None)
         created_by = kwargs.get("createdBy", None)
+        objects = kwargs.get("objects", None)
         object_marking = kwargs.get("objectMarking", None)
         object_label = kwargs.get("objectLabel", None)
         external_references = kwargs.get("externalReferences", None)
@@ -362,6 +398,7 @@ class Opinion:
         explanation = kwargs.get("explanation", None)
         authors = kwargs.get("authors", None)
         opinion = kwargs.get("opinion", None)
+        x_opencti_stix_ids = kwargs.get("x_opencti_stix_ids", None)
         update = kwargs.get("update", False)
 
         if opinion is not None:
@@ -372,7 +409,7 @@ class Opinion:
                         id
                         standard_id
                         entity_type
-                        parent_types                    
+                        parent_types
                     }
                 }
             """
@@ -384,6 +421,7 @@ class Opinion:
                         "createdBy": created_by,
                         "objectMarking": object_marking,
                         "objectLabel": object_label,
+                        "objects": objects,
                         "externalReferences": external_references,
                         "revoked": revoked,
                         "confidence": confidence,
@@ -393,6 +431,7 @@ class Opinion:
                         "explanation": explanation,
                         "authors": authors,
                         "opinion": opinion,
+                        "x_opencti_stix_ids": x_opencti_stix_ids,
                         "update": update,
                     }
                 },
@@ -481,7 +520,7 @@ class Opinion:
                 + "}",
             )
             query = """
-               mutation OpinionEditRelationDelete($id: ID!, $toId: String!, $relationship_type: String!) {
+               mutation OpinionEditRelationDelete($id: ID!, $toId: StixRef!, $relationship_type: String!) {
                    opinionEdit(id: $id) {
                         relationDelete(toId: $toId, relationship_type: $relationship_type) {
                             id
@@ -516,6 +555,13 @@ class Opinion:
         extras = kwargs.get("extras", {})
         update = kwargs.get("update", False)
         if stix_object is not None:
+
+            # Search in extensions
+            if "x_opencti_stix_ids" not in stix_object:
+                stix_object[
+                    "x_opencti_stix_ids"
+                ] = self.opencti.get_attribute_in_extension("stix_ids", stix_object)
+
             return self.create(
                 stix_id=stix_object["id"],
                 createdBy=extras["created_by_id"]
@@ -526,10 +572,11 @@ class Opinion:
                 else None,
                 objectLabel=extras["object_label_ids"]
                 if "object_label_ids" in extras
-                else [],
+                else None,
+                objects=extras["object_ids"] if "object_ids" in extras else [],
                 externalReferences=extras["external_references_ids"]
                 if "external_references_ids" in extras
-                else [],
+                else None,
                 revoked=stix_object["revoked"] if "revoked" in stix_object else None,
                 confidence=stix_object["confidence"]
                 if "confidence" in stix_object
@@ -541,10 +588,13 @@ class Opinion:
                     stix_object["explanation"]
                 )
                 if "explanation" in stix_object
-                else "",
+                else None,
                 authors=self.opencti.stix2.convert_markdown(stix_object["authors"])
                 if "authors" in stix_object
-                else "",
+                else None,
+                x_opencti_stix_ids=stix_object["x_opencti_stix_ids"]
+                if "x_opencti_stix_ids" in stix_object
+                else None,
                 opinion=stix_object["opinion"] if "opinion" in stix_object else None,
                 update=update,
             )
