@@ -1,5 +1,10 @@
 # coding: utf-8
 
+import datetime
+import uuid
+
+from stix2.canonicalization.Canonicalize import canonicalize
+
 
 class StixCoreRelationship:
     def __init__(self, opencti):
@@ -28,6 +33,7 @@ class StixCoreRelationship:
                     entity_type
                     parent_types
                     spec_version
+                    identity_class
                     name
                     description
                     roles
@@ -43,7 +49,7 @@ class StixCoreRelationship:
                                 color
                             }
                         }
-                    }                    
+                    }
                 }
                 ... on Organization {
                     x_opencti_organization_type
@@ -91,6 +97,19 @@ class StixCoreRelationship:
                         external_id
                         created
                         modified
+                        importFiles {
+                            edges {
+                                node {
+                                    id
+                                    name
+                                    size
+                                    metaData {
+                                        mimetype
+                                        version
+                                    }
+                                }
+                            }
+                        }
                     }
                 }
             }
@@ -129,6 +148,9 @@ class StixCoreRelationship:
                 ... on Sector {
                     name
                 }
+                ... on System {
+                    name
+                }
                 ... on Indicator {
                     name
                 }
@@ -164,10 +186,10 @@ class StixCoreRelationship:
                 }
                 ... on Incident {
                     name
-                }         
+                }
                 ... on StixCyberObservable {
                     observable_value
-                }                       
+                }
                 ... on StixCoreRelationship {
                     standard_id
                     spec_version
@@ -210,6 +232,9 @@ class StixCoreRelationship:
                 ... on Sector {
                     name
                 }
+                ... on System {
+                    name
+                }
                 ... on Indicator {
                     name
                 }
@@ -248,7 +273,7 @@ class StixCoreRelationship:
                 }
                 ... on StixCyberObservable {
                     observable_value
-                }                
+                }
                 ... on StixCoreRelationship {
                     standard_id
                     spec_version
@@ -258,6 +283,32 @@ class StixCoreRelationship:
             }
         """
 
+    @staticmethod
+    def generate_id(
+        relationship_type, source_ref, target_ref, start_time=None, stop_time=None
+    ):
+        if isinstance(start_time, datetime.datetime):
+            start_time = start_time.isoformat()
+        if isinstance(stop_time, datetime.datetime):
+            stop_time = stop_time.isoformat()
+        if start_time is not None and stop_time is not None:
+            data = {
+                "relationship_type": relationship_type,
+                "source_ref": source_ref,
+                "target_ref": target_ref,
+                "start_time": start_time,
+                "stop_time": stop_time,
+            }
+        else:
+            data = {
+                "relationship_type": relationship_type,
+                "source_ref": source_ref,
+                "target_ref": target_ref,
+            }
+        data = canonicalize(data, utf8=False)
+        id = str(uuid.uuid5(uuid.UUID("00abedb4-aa42-466c-9c01-fed23315a9b7"), data))
+        return "relationship--" + id
+
     """
         List stix_core_relationship objects
 
@@ -307,7 +358,7 @@ class StixCoreRelationship:
         )
         query = (
             """
-                query StixCoreRelationships($elementId: String, $fromId: String, $fromTypes: [String], $toId: String, $toTypes: [String], $relationship_type: String, $startTimeStart: DateTime, $startTimeStop: DateTime, $stopTimeStart: DateTime, $stopTimeStop: DateTime, $filters: [StixCoreRelationshipsFiltering], $first: Int, $after: ID, $orderBy: StixCoreRelationshipsOrdering, $orderMode: OrderingMode) {
+                query StixCoreRelationships($elementId: [String], $fromId: [String], $fromTypes: [String], $toId: [String], $toTypes: [String], $relationship_type: [String], $startTimeStart: DateTime, $startTimeStop: DateTime, $stopTimeStart: DateTime, $stopTimeStop: DateTime, $filters: [StixCoreRelationshipsFiltering], $first: Int, $after: ID, $orderBy: StixCoreRelationshipsOrdering, $orderMode: OrderingMode) {
                     stixCoreRelationships(elementId: $elementId, fromId: $fromId, fromTypes: $fromTypes, toId: $toId, toTypes: $toTypes, relationship_type: $relationship_type, startTimeStart: $startTimeStart, startTimeStop: $startTimeStop, stopTimeStart: $stopTimeStart, stopTimeStop: $stopTimeStop, filters: $filters, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
                         edges {
                             node {
@@ -481,7 +532,13 @@ class StixCoreRelationship:
 
         self.opencti.log(
             "info",
-            "Creating stix_core_relationship {" + from_id + ", " + to_id + "}.",
+            "Creating stix_core_relationship '"
+            + relationship_type
+            + "' {"
+            + from_id
+            + ", "
+            + to_id
+            + "}.",
         )
         query = """
                 mutation StixCoreRelationshipAdd($input: StixCoreRelationshipAddInput!) {
@@ -526,26 +583,20 @@ class StixCoreRelationship:
         Update a stix_core_relationship object field
 
         :param id: the stix_core_relationship id
-        :param key: the key of the field
-        :param value: the value of the field
+        :param input: the input of the field
         :return The updated stix_core_relationship object
     """
 
     def update_field(self, **kwargs):
         id = kwargs.get("id", None)
-        key = kwargs.get("key", None)
-        value = kwargs.get("value", None)
-        if isinstance(value, list):
-            value = [str(v) for v in value]
-        else:
-            value = str(value)
-        if id is not None and key is not None and value is not None:
+        input = kwargs.get("input", None)
+        if id is not None and input is not None:
             self.opencti.log(
                 "info",
-                "Updating stix_core_relationship {" + id + "} field {" + key + "}.",
+                "Updating stix_core_relationship {" + id + "}",
             )
             query = """
-                    mutation StixCoreRelationshipEdit($id: ID!, $input: EditInput!) {
+                    mutation StixCoreRelationshipEdit($id: ID!, $input: [EditInput]!) {
                         stixCoreRelationshipEdit(id: $id) {
                             fieldPatch(input: $input) {
                                 id
@@ -556,7 +607,11 @@ class StixCoreRelationship:
                     }
                 """
             result = self.opencti.query(
-                query, {"id": id, "input": {"key": key, "value": value}}
+                query,
+                {
+                    "id": id,
+                    "input": input,
+                },
             )
             return self.opencti.process_multiple_fields(
                 result["data"]["stixCoreRelationshipEdit"]["fieldPatch"]
@@ -689,7 +744,7 @@ class StixCoreRelationship:
                 + "}",
             )
             query = """
-               mutation StixCoreRelationshipRemoveRelation($id: ID!, $toId: String!, $relationship_type: String!) {
+               mutation StixCoreRelationshipRemoveRelation($id: ID!, $toId: StixRef!, $relationship_type: String!) {
                    stixCoreRelationshipEdit(id: $id) {
                         relationDelete(toId: $toId, relationship_type: $relationship_type) {
                             id
@@ -831,7 +886,7 @@ class StixCoreRelationship:
                 + "}",
             )
             query = """
-               mutation StixCoreRelationshipRemoveRelation($id: ID!, $toId: String!, $relationship_type: String!) {
+               mutation StixCoreRelationshipRemoveRelation($id: ID!, $toId: StixRef!, $relationship_type: String!) {
                    stixCoreRelationshipEdit(id: $id) {
                         relationDelete(toId: $toId, relationship_type: $relationship_type) {
                             id
@@ -920,7 +975,7 @@ class StixCoreRelationship:
                 + "}",
             )
             query = """
-               mutation StixCoreRelationshipRemoveRelation($id: ID!, $toId: String!, $relationship_type: String!) {
+               mutation StixCoreRelationshipRemoveRelation($id: ID!, $toId: StixRef!, $relationship_type: String!) {
                    stixCoreRelationshipEdit(id: $id) {
                         relationDelete(toId: $toId, relationship_type: $relationship_type) {
                             id
@@ -991,7 +1046,7 @@ class StixCoreRelationship:
             stix_domain_object = self.read(id=id, customAttributes=custom_attributes)
             if stix_domain_object["createdBy"] is not None:
                 query = """
-                    mutation StixCoreRelationshipEdit($id: ID!, $toId: String! $relationship_type: String!) {
+                    mutation StixCoreRelationshipEdit($id: ID!, $toId: StixRef! $relationship_type: String!) {
                         stixCoreRelationshipEdit(id: $id) {
                             relationDelete(toId: $toId, relationship_type: $relationship_type) {
                                 id
@@ -1043,40 +1098,8 @@ class StixCoreRelationship:
         update = kwargs.get("update", False)
         default_date = kwargs.get("defaultDate", False)
         if stix_relation is not None:
-
-            # TODO: Compatibility with OpenCTI 3.X to be REMOVED
-            if "confidence" not in stix_relation:
-                stix_relation["confidence"] = (
-                    stix_relation["x_opencti_weight"]
-                    if "x_opencti_weight" in stix_relation
-                    else 0
-                )
-            if "start_time" not in stix_relation:
-                stix_relation["start_time"] = (
-                    stix_relation["x_opencti_first_seen"]
-                    if "x_opencti_first_seen" in stix_relation
-                    else None
-                )
-            if "stop_time" not in stix_relation:
-                stix_relation["stop_time"] = (
-                    stix_relation["x_opencti_last_seen"]
-                    if "x_opencti_last_seen" in stix_relation
-                    else None
-                )
-            if stix_relation["relationship_type"] == "gathering":
-                stix_relation["relationship_type"] = "part-of"
-            elif stix_relation["relationship_type"] == "localization":
-                stix_relation["relationship_type"] = "located-at"
-            source_ref = (
-                stix_relation["x_opencti_source_ref"]
-                if "x_opencti_source_ref" in stix_relation
-                else stix_relation["source_ref"]
-            )
-            target_ref = (
-                stix_relation["x_opencti_target_ref"]
-                if "x_opencti_target_ref" in stix_relation
-                else stix_relation["target_ref"]
-            )
+            source_ref = stix_relation["source_ref"]
+            target_ref = stix_relation["target_ref"]
             return self.create(
                 fromId=source_ref,
                 toId=target_ref,
