@@ -22,6 +22,7 @@ class StixObjectOrStixRelationship:
                         entity_type
                         parent_types
                         spec_version
+                        identity_class
                         name
                         description
                         roles
@@ -37,7 +38,7 @@ class StixObjectOrStixRelationship:
                                     color
                                 }
                             }
-                        }                        
+                        }
                     }
                     ... on Organization {
                         x_opencti_organization_type
@@ -105,7 +106,7 @@ class StixObjectOrStixRelationship:
                     edges {
                         node {
                             id
-                            standard_id                            
+                            standard_id
                             entity_type
                             kill_chain_name
                             phase_name
@@ -144,7 +145,6 @@ class StixObjectOrStixRelationship:
                 description
                 report_types
                 published
-                x_opencti_report_status
             }
             ... on CourseOfAction {
                 name
@@ -173,6 +173,12 @@ class StixObjectOrStixRelationship:
                 contact_information
                 x_opencti_aliases
             }
+            ... on System {
+                name
+                description
+                contact_information
+                x_opencti_aliases
+            }
             ... on Indicator {
                 pattern_type
                 pattern_version
@@ -254,7 +260,7 @@ class StixObjectOrStixRelationship:
                     edges {
                         node {
                             id
-                            standard_id                            
+                            standard_id
                             entity_type
                             kill_chain_name
                             phase_name
@@ -318,6 +324,24 @@ class StixObjectOrStixRelationship:
                 last_seen
                 objective
             }
+            ... on Event {
+                name
+                description
+              }
+             ... on Channel {
+                name
+                description
+              }
+             ... on Narrative {
+                name
+                description
+              }
+             ... on Language {
+                name
+            }
+            ... on StixCyberObservable {
+                observable_value
+            }
             ... on StixCoreRelationship {
                 createdBy {
                     ... on Identity {
