@@ -1,6 +1,9 @@
 # coding: utf-8
 
 import json
+import uuid
+
+from stix2.canonicalization.Canonicalize import canonicalize
 
 
 class Tool:
@@ -37,7 +40,7 @@ class Tool:
                                 color
                             }
                         }
-                    }                    
+                    }
                 }
                 ... on Organization {
                     x_opencti_organization_type
@@ -114,7 +117,7 @@ class Tool:
                 edges {
                     node {
                         id
-                        standard_id                            
+                        standard_id
                         entity_type
                         kill_chain_name
                         phase_name
@@ -139,6 +142,14 @@ class Tool:
             }
         """
 
+    @staticmethod
+    def generate_id(name):
+        name = name.lower().strip()
+        data = {"name": name}
+        data = canonicalize(data, utf8=False)
+        id = str(uuid.uuid5(uuid.UUID("00abedb4-aa42-466c-9c01-fed23315a9b7"), data))
+        return "tool--" + id
+
     """
         List Tool objects
 
@@ -226,7 +237,7 @@ class Tool:
 
     """
         Read a Tool object
-        
+
         :param id: the id of the Tool
         :param filters: the filters to apply if no id provided
         :return Tool object
@@ -349,6 +360,13 @@ class Tool:
         extras = kwargs.get("extras", {})
         update = kwargs.get("update", False)
         if stix_object is not None:
+
+            # Search in extensions
+            if "x_opencti_stix_ids" not in stix_object:
+                stix_object[
+                    "x_opencti_stix_ids"
+                ] = self.opencti.get_attribute_in_extension("stix_ids", stix_object)
+
             return self.opencti.tool.create(
                 stix_id=stix_object["id"],
                 createdBy=extras["created_by_id"]
